@@ -2,6 +2,7 @@ import torch
 import numpy as np
 import pandas as pd
 import transformers
+from sklearn.metrics import precision_recall_fscore_support
 
 from BERT_STEM.Encode import *
 from BERT_STEM.TrainBERT4PT import *
@@ -112,6 +113,20 @@ class BertSTEMForTextClassification:
         encoded_dict['labels'] = torch.tensor(labels, dtype=torch.long)
 
         return(encoded_dict)
+    
+    def _compute_metrics(self, pred):
+        
+        labels = pred.label_ids
+        preds = pred.predictions.argmax(-1)
+        precision, recall, f1, _ = precision_recall_fscore_support(labels, preds, average='weighted')
+        acc = accuracy_score(labels, preds)
+
+        return {
+            'accuracy': acc,
+            'f1': f1,
+            'precision': precision,
+            'recall': recall
+        }
 
 
     def _train(self, inputs_train, inputs_val, num_train_epochs=3, learning_rate=1e-5, load_best_model_at_end=True, early_stopping_patience=5):
@@ -145,7 +160,8 @@ class BertSTEMForTextClassification:
                                args=training_args,                  # training arguments, defined above
                                train_dataset=dataset_train,               # training dataset
                                eval_dataset=dataset_val,                # evaluation dataset
-                               callbacks = callbacks)
+                               callbacks = callbacks,
+                               compute_metrics=self._compute_metrics)
 
         trainer.train()
 
@@ -173,3 +189,29 @@ class BertSTEMForTextClassification:
             logits = self._model(encoded_text['input_ids'])['logits']
         
         return(torch.nn.Softmax()(logits))
+
+
+    def trainer_evaluate(self, df, col_text, col_labels, batch_size=8):
+
+        encoded = self._get_inputs_from_df(df, col_text, col_labels)
+        dataset = CorpusDataset(encoded)
+
+
+
+        training_args = transformers.TrainingArguments(output_dir='./results',          # output directory
+                                                       num_train_epochs=3,              # total # of training epochs
+                                                       per_device_train_batch_size=8,  # batch size per device during training
+                                                       per_device_eval_batch_size=batch_size,   # batch size for evaluation
+                                                       warmup_steps=500,                # number of warmup steps for learning rate scheduler
+                                                       weight_decay=0.01,               # strength of weight decay
+                                                       logging_dir='./logs',
+                                                       evaluation_strategy="epoch",
+                                                       save_strategy = "epoch")
+
+        trainer = transformers.Trainer(model=self._model,                         # the instantiated Transformers model to be trained
+                                       args=training_args,                  # training arguments, defined above
+                                       train_dataset=dataset)
+
+        output = trainer.predict(dataset)
+
+        return(output)
